//////////////////////////////////////////
//
//	FlexInc. 2012
//	http://www.loziosecchi.it/flex_inc
//	http://twitter.com/loziosecchi
//
//////////////////////////////////////////

package flexInc.ane.android.docLauncher;

import java.io.File;

import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.net.Uri;
import android.webkit.MimeTypeMap;
import android.widget.Toast;

import com.adobe.fre.FREContext;
import com.adobe.fre.FREFunction;
import com.adobe.fre.FREObject;

public class DocLauncherOpenFunction implements FREFunction {

	@Override
	public FREObject call(FREContext context, FREObject[] args) {
				
		FREObject returnValue = null;
		
		try {
			// getting the file url from passed application parameters
			String fileUrl = args[0].getAsString();

			// getting the file
			File docFile = new File(fileUrl);

			if(docFile.exists())
			{
				// create the intent, used to visualize the document 
				Intent intent = new Intent();
				intent.setAction(Intent.ACTION_VIEW);

				// getting doc Uri
				Uri fileUri = Uri.fromFile(docFile);

				// getting doc mimeType
				MimeTypeMap mime = MimeTypeMap.getSingleton();
				String extension = MimeTypeMap.getFileExtensionFromUrl(fileUrl);
				String mimeType = mime.getMimeTypeFromExtension(extension);
				
				intent.setDataAndType(fileUri, mimeType);

				// Start activity
				DocLauncherExtensionContext extensionContext = (DocLauncherExtensionContext) context;
				Activity activity = extensionContext.getActivity();

				try
				{
					activity.startActivity(intent);
					
					returnValue = FREObject.newObject(true);					
				}catch (ActivityNotFoundException e) {
					// getting custom for a system error
					String noActivityErrorMessage = args[3].getAsString();
					
					// flag for showing the error in the toast
					Boolean showNoActivityErrorInfo = args[4].getAsBool();
					
					String message = "Error:";
					
					if(noActivityErrorMessage.length() != 0)
						message = noActivityErrorMessage;
					
					if(showNoActivityErrorInfo == true)
						message += " " + e.getMessage();

					Toast.makeText(context.getActivity(), message, Toast.LENGTH_LONG).show();					

					returnValue = FREObject.newObject(false);					
				}
			}else
			{
				// if the file does not exists, show a toast message
				String message = "No file found:";

				// getting custom message for a file not found
				String fileNotFoundMessage = args[1].getAsString();
				
				// flag for showing the file url in the toast
				Boolean showFileNotFoundUrl = args[2].getAsBool();				

				if(fileNotFoundMessage.length() != 0)
					message = fileNotFoundMessage;
				
				if(showFileNotFoundUrl == true)
					message += " " + fileUrl;

				Toast.makeText(context.getActivity(), message, Toast.LENGTH_LONG).show();					

				returnValue = FREObject.newObject(false);
			}
		}catch (Exception e) {
			Toast.makeText(context.getActivity(), "Error: " + e.getMessage(), Toast.LENGTH_LONG).show();			
		}

		return returnValue;
	}

}
